//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/>.
//

#ifndef TEXTFORMATTER_H
#define TEXTFORMATTER_H

#include <iosfwd>
#include <map>
#include <vector>
#include <deque>
#include <list>


template<class Key, class T>
std::ostream &operator<<(std::ostream &s, const std::map<Key, T> &v)
{
    s << "[";
    for(typename std::map<Key, T>::const_iterator it = v.begin(); it!=v.end(); ++it) {
        if (it != v.begin())
            s << ",";
        s << "[" << (*it).first << "]:";
        s << (*it).second;
    }
    s << "]";
    return s;
}

template<class T>
std::ostream &operator<<(std::ostream &s, const std::vector<T> &v)
{
    s << "[";
    for(typename std::vector<T>::const_iterator it = v.begin(); it!=v.end(); ++it) {
        if (it != v.begin())
            s << ",";
        s << (*it);
    }
    s << "]";
    return s;
}

template<class T>
std::ostream &operator<<(std::ostream &s, const std::deque<T> &v)
{
    s << "[";
    for(typename std::deque<T>::const_iterator it = v.begin(); it!=v.end(); ++it) {
        if (it != v.begin())
            s << ",";
        s << (*it);
    }
    s << "]";
    return s;
}

template<class T>
std::ostream &operator<<(std::ostream &s, const std::list<T> &v)
{
    s << "[";
    for(typename std::list<T>::const_iterator it = v.begin(); it!=v.end(); ++it) {
        if (it != v.begin())
            s << ",";
        s << (*it);
    }
    s << "]";
    return s;
}

#endif // TEXTFORMATTER_H
